@@ -303,7 +303,7 @@ xfpm_manager_shutdown (XfpmManager *manager)
 {
   GError *error = NULL;
 
-  if ( LOGIND_RUNNING () )
+  if (manager->priv->systemd != NULL)
     xfpm_systemd_shutdown (manager->priv->systemd, &error );
   else
     xfpm_console_kit_shutdown (manager->priv->console, &error );
@@ -418,7 +418,7 @@ xfpm_manager_lid_changed_cb (XfpmPower *power, gboolean lid_is_closed, XfpmManag
   XfpmLidTriggerAction action;
   gboolean on_battery, logind_handle_lid_switch;
 
-  if ( LOGIND_RUNNING() )
+  if (manager->priv->systemd != NULL)
   {
     g_object_get (G_OBJECT (manager->priv->conf),
                   LOGIND_HANDLE_LID_SWITCH, &logind_handle_lid_switch,
@@ -641,10 +641,10 @@ xfpm_manager_inhibit_sleep_systemd (XfpmManager *manager)
   const char *why = "xfce4-power-manager handles these events";
   const char *mode = "block";
 
-  if (g_strcmp0(what, "") == 0)
+  if (manager->priv->systemd == NULL)
     return -1;
 
-  if (!(LOGIND_RUNNING()))
+  if (g_strcmp0 (what, "") == 0)
     return -1;
 
   XFPM_DEBUG ("Inhibiting systemd sleep: %s", what);
@@ -964,7 +964,7 @@ GHashTable *xfpm_manager_get_config (XfpmManager *manager)
 
   hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
 
-  if ( LOGIND_RUNNING () )
+  if (manager->priv->systemd != NULL)
   {
     g_object_get (G_OBJECT (manager->priv->systemd),
                   "can-shutdown", &can_shutdown,
