@@ -46,7 +46,6 @@ static void xfpm_xfconf_finalize   (GObject *object);
 struct XfpmXfconfPrivate
 {
   XfconfChannel   *channel;
-  XfconfChannel   *session_channel;
   GValue          *values;
 };
 
@@ -144,7 +143,7 @@ xfpm_xfconf_get_property (GObject *object,
 }
 
 static void
-xfpm_xfconf_load (XfpmXfconf *conf, gboolean channel_valid)
+xfpm_xfconf_load (XfpmXfconf *conf)
 {
   GParamSpec **specs;
   GValue value = { 0, };
@@ -159,7 +158,7 @@ xfpm_xfconf_load (XfpmXfconf *conf, gboolean channel_valid)
     prop_name = g_strdup_printf ("%s%s", XFPM_PROPERTIES_PREFIX, specs[i]->name);
     g_value_init (&value, specs[i]->value_type);
 
-    if (channel_valid)
+    if (conf->priv->channel != NULL)
     {
       if ( !xfconf_channel_get_property (conf->priv->channel, prop_name, &value) )
       {
@@ -206,31 +205,6 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
   g_object_set_property (G_OBJECT (conf), property + strlen (XFPM_PROPERTIES_PREFIX), value);
 }
 
-static void
-xfpm_xfsession_property_changed_cb (XfconfChannel *channel, gchar *property,
-         GValue *value, XfpmXfconf *conf)
-{
-  /*FIXME: Set default for this key*/
-  if ( G_VALUE_TYPE(value) == G_TYPE_INVALID )
-    return;
-
-  XFPM_DEBUG ("property %s\n", property);
-
-  if ( g_strcmp0 (property, "/shutdown/LockScreen") != 0)
-    return;
-
-  /* sanity check */
-  if ( !G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) )
-    return;
-
-  XFPM_DEBUG ("Property modified: %s\n", property);
-
-  /* update xfconf which will update xfpm and keep things in sync */
-  xfconf_channel_set_bool (conf->priv->channel,
-                           XFPM_PROPERTIES_PREFIX LOCK_SCREEN_ON_SLEEP,
-                           g_value_get_boolean(value));
-}
-
 static void
 xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 {
@@ -648,8 +622,6 @@ static void
 xfpm_xfconf_init (XfpmXfconf *conf)
 {
   GError *error = NULL;
-  gboolean channel_valid;
-  gboolean lock_screen;
 
   conf->priv = xfpm_xfconf_get_instance_private (conf);
 
@@ -662,35 +634,14 @@ xfpm_xfconf_init (XfpmXfconf *conf)
       g_critical ("xfconf_init failed: %s\n", error->message);
       g_error_free (error);
     }
-    channel_valid = FALSE;
   }
   else
   {
     conf->priv->channel = xfconf_channel_get (XFPM_CHANNEL);
-    conf->priv->session_channel = xfconf_channel_get ("xfce4-session");
-
-    /* if xfce4-session is around, sync to it on startup */
-    if ( xfconf_channel_has_property (conf->priv->session_channel, "/shutdown/LockScreen") )
-    {
-      lock_screen = xfconf_channel_get_bool (conf->priv->session_channel,
-                                             "/shutdown/LockScreen",
-                                             TRUE);
-
-      XFPM_DEBUG("lock screen %s", lock_screen ? "TRUE" : "FALSE");
-
-      g_object_set (G_OBJECT (conf), LOCK_SCREEN_ON_SLEEP, lock_screen, NULL);
-    }
-
     g_signal_connect (conf->priv->channel, "property-changed",
                       G_CALLBACK (xfpm_xfconf_property_changed_cb), conf);
-
-    /* watch for session's property change so we can stay in sync */
-    g_signal_connect (conf->priv->session_channel, "property-changed",
-                      G_CALLBACK (xfpm_xfsession_property_changed_cb), conf);
-
-    channel_valid = TRUE;
   }
-  xfpm_xfconf_load (conf, channel_valid);
+  xfpm_xfconf_load (conf);
 }
 
 static void
@@ -709,6 +660,9 @@ xfpm_xfconf_finalize(GObject *object)
 
   g_free (conf->priv->values);
 
+  if (conf->priv->channel != NULL)
+    xfconf_shutdown ();
+
   G_OBJECT_CLASS (xfpm_xfconf_parent_class)->finalize(object);
 }
 
